# Coderschool Exam Client

![Version](https://img.shields.io/badge/Latest%20Version-v0.0.3-%2300b4d8.svg?&style=for-the-badge&logo=git&logoColor=white)
![Python](https://img.shields.io/badge/Python-%230096c7.svg?&style=for-the-badge&logo=python&logoColor=white)
![Google Colab](https://img.shields.io/badge/Google%20Colab-4285F4?style=for-the-badge&logo=googledrive&logoColor=white)

Update (29 Sep 2024): Publish package to PyPi

## About the project
**cspyexamclient** is a Python client for interacting with online exam system. It allows students to register, answer questions, and submit their answers. The client uses `ipywidgets` for creating interactive widgets in ipython notebooks before uploading students answers to the exam server.

## Features

- **Register Student**: Allows students to register using their email.
- **Generate Questions**: Dynamically displays questions and answer options.
- **Display Submission Summary**: Displays a summary of all questions and corresponding answers.
- **Submit Answers**: Submits student answers to the server.

### Submit - Resubmit - Reset

<img width="500" src="assets/test_submission.gif">

### Exam Summary

<img width="500" src="assets/exam_summary.png">

## Exam notebook
| Module       | Description       | Link                                                                                  |
|--------------|-------------------|---------------------------------------------------------------------------------------|
| M1.1         | Basic SQL         | https://colab.research.google.com/drive/1E3sppN-vjschXS46WTeqZnQSmRBcuggN?usp=sharing |
| M1.2         | Advanced SQL      | https://colab.research.google.com/drive/1i-aGTjpXL-En8kVFB0Cl8elHn9Z866yv?usp=sharing |
| M2.1         | Python 101        | https://colab.research.google.com/drive/1zX-ZgjEot_uGHh8x2nCl7hGWUklLuYeL?usp=sharing |
| M3.1         | Pandas 101        | https://colab.research.google.com/drive/143rJnko61nMUGGwMccgxaBJRA-CmJEqT?usp=sharing |
| M4.1         | Data Visualization| Exam is coding and feedback thus no questions generation needed                       |